@@ -474,11 +474,11 @@ struct Page	*page;
 
 	 set_cursor(page, cursor_x, cursor_y);
 
-	 if(search.type==SEARCH_NO) {    /* prevent forced reactivation after text search (cursor position has to be kept in this case) */
-	    search.type=SEARCH_NO;    /* only jump to search position once */
-	    if(active_link>=0)    /* some link active -> force highlighting (necessary after reloading from history) */
-	       activate_link(page, active_link);
-	 }
+	 /* restore link active before positioning cursor */
+	 if(search.type==SEARCH_NO)    /* unless returning from a search (in which case cursor position must take precedence) */
+	    activate_link(page, active_link);
+	 else
+	    search.type=SEARCH_NO;    /* only first reload after search handled specially */
       }
    }
 
@@ -895,5 +895,5 @@ struct Page	*page;
    } while(quit==RET_NO);
 
    end_fullscreen();
-   return quit;    /* main program needs to know whether to quit or to enter command prompt */
+   return quit;    /* tell main program what to do (why did pager exit?) */
 }
