@@ -6,7 +6,7 @@
 /*
  * parse-syntax.c -- this one parses the HTML file to a parse tree.
  *
- * (C) 2001 - 2004 antrik
+ * (C) 2001 - 2004, 2008 antrik
  *
  * The generated parse tree contains all HTML elements, their attributes, and
  * all content. (Text inside the elements.)
@@ -281,7 +281,7 @@ enum Syntax_error	*err_level;    /* return: syntax errors encountered in page */
       DMSG(("%c", in));
 
       new_cr_mode=0;
-      if(tolower(in)>='a' && tolower(in)<='z')    /* letter */
+      if((in|32)>='a' && (in|32)<='z')    /* letter */
 	 dispatch_char='a';    /* indicated by 'a' (shared dispatch case) */
       else if(in>='0' && in<='9')    /* digit */
 	 dispatch_char='0';
@@ -296,7 +296,7 @@ enum Syntax_error	*err_level;    /* return: syntax errors encountered in page */
 	    new_cr_mode=1;    /* if real '\n' follows, it has to be discarded */
 	 }
 	 dispatch_char=' ';
-      } else if(!iscntrl(in) && strchr("&<>\";=/\'-![?#", in)==NULL)    /* other normal character (not control char and no html function in any situation) */
+      } else if((unsigned char)in>=32 && in!=127 && strchr("&<>\";=/\'-![?#", in)==NULL)    /* other normal character (not control char and no html function in any situation) */
 	 dispatch_char='$';
       else    /* characters which may have html function */
 	 dispatch_char=in;    /* handled each seperately in dispatcher */
